@@ -490,6 +490,8 @@ def apply(for_real, send_mail, random):
                     message += foo
                 else:
                     message += "Aucun client à FUPer\n"
+                if total_client == 0:
+                    total_client = 1
                 fup_false = total_client - fup_true
                 pourcentage_fup = fup_true * 100 / total_client
                 pourcentage_fup = round(pourcentage_fup)
