@@ -7,7 +7,7 @@ from .consts import CONFIG
 from .consts import FUPDB_CREDENTIALS
 from .consts import LOGS
 from .consts import REDIS_DB
-from .consts import REST_CLIENT
+from .consts import REST_CLIENT, URL
 from . import core
 from . import product
 
@@ -231,25 +231,37 @@ class Customer(object):
         api_request = getattr(REST_CLIENT, method)
         LOGS.logger.info(api_request)
         LOGS.logger.info(params)
-        response = api_request(
-            '/fup',
+        # response = api_request(
+        #     '/fup',
+        #     auth=(
+        #         CONFIG['AIGUILLIER']['username'],
+        #         CONFIG['AIGUILLIER']['password']
+        #         ),
+        #     params=params
+        #     )
+        response = requests.delete(
+            '{}/consommation?remettre_normal={}&periode={}'.format(
+                URL,
+                self.nam,
+                period
+                ),
             auth=(
                 CONFIG['AIGUILLIER']['username'],
                 CONFIG['AIGUILLIER']['password']
-                ),
-            params=params
+                )
             )
+        response = response.json()
         LOGS.logger.info('AIGUILLIER RESPONSE: {}'.format(
-            response['content']
+            response
             ))
         LOGS.logger.info("{} un client {}-{}-{}-{}".format(
             msg,
             self.name,
             policy_name,
             period,
-            response['content']['status']
+            response['status']
             ))
-        if (response['content']['status']).lower() == '200':
+        if (response['status']).lower() == '200':
             url = core.database_url(**FUPDB_CREDENTIALS)
             with records.Database(url) as db:
                 sql = (
